@@ -150,9 +150,10 @@ class VaspJob(Job):
         return "Vasp Job"
 
     @staticmethod
-    def aflow_style_run(vasp_command):
+    def double_relaxation_run(vasp_command):
         """
-        Returns a list of two jobs corresponding to an AFLOW style run.
+        Returns a list of two jobs corresponding to an AFLOW style double
+        relaxation run.
 
         Args:
             vasp_command:
@@ -167,12 +168,11 @@ class VaspJob(Job):
                 VaspJob(
                     vasp_command, final=True, backup=False,
                     suffix=".relax2", gzipped=True,
-                    settings_override=[{"dict": "INCAR",
-                                        "action": {"_set": {"ISTART": 1}}},
-                                       {"filename": "CONTCAR",
-                                        "action":
-                                            {"_file_copy":
-                                                 {"dest": "POSCAR"}}}])]
+                    settings_override=[
+                        {"dict": "INCAR",
+                         "action": {"_set": {"ISTART": 1}}},
+                        {"filename": "CONTCAR",
+                         "action": {"_file_copy": {"dest": "POSCAR"}}}])]
 
 
 def gzip_directory(path):
